<?php
if (!function_exists('getFolders')) {
    function getFolders($dir, $search = '') {
        $folders = array_filter(glob($dir . '/*', GLOB_ONLYDIR), function($folder) use ($search) {
            return empty($search) || stripos(basename($folder), $search) !== false;
        });
        return array_map('basename', $folders);
    }
}

if (!function_exists('getImages')) {
    function getImages($dir) {
        return glob($dir . '/*.{jpg,jpeg,png,gif}', GLOB_BRACE);
    }
}

if (!function_exists('get_folders')) {
    function get_folders($root_dir, $search = '') {
        $folders = glob($root_dir . '/*', GLOB_ONLYDIR);
        if ($search) {
            $folders = array_filter($folders, function($folder) use ($search) {
                return stripos(basename($folder), $search) !== false;
            });
        }
        return $folders;
    }
}

if (!function_exists('generatePagination')) {
    function generatePagination($current_page, $total_pages, $url_prefix = '?') {
        $pagination = '<div class="pagination">';
        if ($current_page > 1) {
            $pagination .= '<a href="' . $url_prefix . 'page=' . ($current_page - 1) . '">上一页</a>';
        }
        $pagination .= '<a href="' . $url_prefix . 'page=1">首页</a>';
        if ($current_page < $total_pages) {
            $pagination .= '<a href="' . $url_prefix . 'page=' . ($current_page + 1) . '">下一页</a>';
        }
        $pagination .= '</div>';
        return $pagination;
    }
}

if (!function_exists('create_thumbnail')) {
    function create_thumbnail($src_path, $thumb_path, $max_width = 200, $max_height = 200) {
        if (file_exists($thumb_path)) {
            return;
        }

        list($width, $height, $type) = getimagesize($src_path);
        $ratio = min($max_width / $width, $max_height / $height);
        $new_width = $width * $ratio;
        $new_height = $height * $ratio;

        $thumb = imagecreatetruecolor($new_width, $new_height);

        switch ($type) {
            case IMAGETYPE_JPEG:
                $source = imagecreatefromjpeg($src_path);
                break;
            case IMAGETYPE_PNG:
                $source = imagecreatefrompng($src_path);
                imagealphablending($thumb, false);
                imagesavealpha($thumb, true);
                break;
            case IMAGETYPE_GIF:
                $source = imagecreatefromgif($src_path);
                break;
            default:
                return false;
        }

        imagecopyresampled($thumb, $source, 0, 0, 0, 0, $new_width, $new_height, $width, $height);

        switch ($type) {
            case IMAGETYPE_JPEG:
                imagejpeg($thumb, $thumb_path, 90);
                break;
            case IMAGETYPE_PNG:
                imagepng($thumb, $thumb_path);
                break;
            case IMAGETYPE_GIF:
                imagegif($thumb, $thumb_path);
                break;
        }

        imagedestroy($thumb);
        imagedestroy($source);

        return true;
    }
}

if (!function_exists('getDirs')) {
    function getDirs() {
        $baseDir = __DIR__ . '/images';
        $dirs = glob($baseDir . '/*', GLOB_ONLYDIR);
        return $dirs ? $dirs : [];
    }
}

if (!function_exists('generateTags')) {
    function generateTags() {
        $dirs = getDirs();
        $tags = [];
        
        foreach ($dirs as $dir) {
            $dirName = basename($dir);
            $words = preg_split('/\s+/', $dirName);
            foreach ($words as $word) {
                if (mb_strlen($word) <= 16) {
                    if (isset($tags[$word])) {
                        $tags[$word]++;
                    } else {
                        $tags[$word] = 1;
                    }
                }
            }
        }
        
        arsort($tags);
        return array_slice($tags, 0, 50);
    }
}

if (!function_exists('getTagDirs')) {
    function getTagDirs($tag) {
        $dirs = getDirs();
        $tagDirs = [];
        
        foreach ($dirs as $dir) {
            if (stripos(basename($dir), $tag) !== false) {
                $tagDirs[] = $dir;
            }
        }
        
        return $tagDirs;
    }
}

if (!function_exists('getThumbnail')) {
    function getThumbnail($dir) {
        $images = glob($dir . '/*.{jpg,jpeg,png,gif}', GLOB_BRACE);
        if (!empty($images)) {
            $firstImage = $images[0];
            $thumbDir = __DIR__ . '/thumbnails/' . basename($dir);
            if (!file_exists($thumbDir)) {
                mkdir($thumbDir, 0777, true);
            }
            $thumbPath = $thumbDir . '/' . basename($firstImage);
            if (!file_exists($thumbPath)) {
                create_thumbnail($firstImage, $thumbPath);
            }
            return $thumbPath;
        }
        return null;
    }
}

function getThumbnail($dir) {
    $images = glob($dir . '/*.{jpg,jpeg,png,gif}', GLOB_BRACE);
    return !empty($images) ? $images[0] : false;
}
