<?php
ini_set('memory_limit', '256M');
require_once 'config.php';
require_once 'functions.php';

$dir = isset($_GET['dir']) ? $_GET['dir'] : '';

if (!is_dir($dir)) {
    die('Invalid directory');
}

$images = glob($dir . '/*.{jpg,jpeg,png,gif}', GLOB_BRACE);

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo htmlspecialchars($folder_name); ?></title>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 15px;
            box-sizing: border-box;
        }
        .gallery {
            width: 100%;
            margin: 0 auto;
        }
        .gallery-item {
            width: calc(33.33% - 4px);
            margin-bottom: 8px;
            box-sizing: border-box;
        }
        .gallery-item img {
			grid-template-columns: repeat(3,minmax(0,1fr));
            width: 100%;
            height: auto;
            display: block;
        }
        .fullscreen-overlay {
            display: none;
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background-color: rgba(0, 0, 0, 0.9);
            z-index: 1000;
            overflow: auto;
        }
        .fullscreen-image {
            display: block;
            margin: auto;
            max-width: 90%;
            max-height: 90%;
            position: absolute;
            top: 50%;
            left: 50%;
            transform: translate(-50%, -50%);
        }
        .close-button {
            position: absolute;
            top: 20px;
            right: 30px;
            color: #f1f1f1;
            font-size: 40px;
            font-weight: bold;
            cursor: pointer;
        }
    </style>
</head>
<body>

 <h1><?php echo htmlspecialchars($folder); ?></h1>
    <div class="gallery" id="gallery">
        <?php foreach ($images as $image): ?>
            <div class="gallery-item">
                <img class="lazy" src="<?php echo str_replace($_SERVER['DOCUMENT_ROOT'], '', $image); ?>" alt="Image" onclick="openFullscreen(this.src)">
            </div>
        <?php endforeach; ?>
    </div>
    
    <div id="fullscreenOverlay" class="fullscreen-overlay">
        <span class="close-button" onclick="closeFullscreen()">&times;</span>
        <img id="fullscreenImage" class="fullscreen-image" src="" alt="Fullscreen Image">
    </div>

    <script src="https://unpkg.com/masonry-layout@4/dist/masonry.pkgd.min.js"></script>
    <script src="https://unpkg.com/imagesloaded@5/imagesloaded.pkgd.min.js"></script>
    <script>
        function openFullscreen(imgSrc) {
            document.getElementById('fullscreenImage').src = imgSrc;
            document.getElementById('fullscreenOverlay').style.display = 'block';
        }

        function closeFullscreen() {
            document.getElementById('fullscreenOverlay').style.display = 'none';
        }

        document.addEventListener('DOMContentLoaded', function() {
            var grid = document.querySelector('.gallery');
            var msnry;

            imagesLoaded(grid, function() {
                msnry = new Masonry(grid, {
                    itemSelector: '.gallery-item',
                    columnWidth: '.gallery-item',
                    gutter: 2,
                    percentPosition: true
                });
            });
        });
		//懒加载
		document.addEventListener('DOMContentLoaded', function() {
    var lazyLoadInstance = new LazyLoad({
        elements_selector: ".lazy"
    });

    var grid = document.querySelector('.gallery');
    var msnry;

    imagesLoaded(grid, function() {
        msnry = new Masonry(grid, {
            itemSelector: '.gallery-item',
            columnWidth: '.gallery-item',
            gutter: 2,
            percentPosition: true
        });
    });
});

    </script>
</body>
</html>
