<?php

require_once 'config.php';
require_once 'functions.php';

$page = isset($_GET['page']) ? intval($_GET['page']) : 1;
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$items_per_page = 12;

$folders = get_folders(ROOT_DIR, $search);
$total_pages = ceil(count($folders) / $items_per_page);
$folders = array_slice($folders, ($page - 1) * $items_per_page, $items_per_page);
            $folder_name = basename($folder);

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Image Gallery</title>
    <style>
    .gallery {
        display: grid;
        grid-template-columns: repeat(4, 1fr);
        gap: 10px;  /* 减小了间隔 */
        grid-gap: 10px;  /* 为了兼容性，同时使用gap和grid-gap */
    }
    .folder {
        text-align: center;
    }
    .folder img {
        width: 100%;  /* 改为100%以适应容器 */
        height: 192px;
        object-fit: cover;
    }
    .pagination {
        text-align: center;
        margin-top: 20px;
        display: flex;
        justify-content: center;
        align-items: center;
        flex-wrap: wrap;
    }
    .pagination > * {
        margin: 0 5px;  /* 减小了边距 */
    }
    .pagination .disabled {
        color: #999;
        cursor: not-allowed;
    }
    .pagination .page-info {
        margin: 0 10px;  /* 减小了边距 */
    }
    .search {
        text-align: center;
        line-height: 100%;
        font-size: 18px;
        background: #f4f4f4;
        padding: 10px 0;  /* 添加了一些内边距 */
    }
</style>

</head>
<body>
    <h1>Image Gallery</h1>
    <form action="" class="search" method="get">
        <input type="text" name="search" value="<?php echo htmlspecialchars($search); ?>" placeholder="Search folders">
        <input type="submit" value="Search">
    </form>
    <div class="gallery">
        <?php foreach ($folders as $folder): ?>
            <?php
            $folder_name = basename($folder);
            $images = glob($folder . '/*.{jpg,jpeg,png,gif}', GLOB_BRACE);
            if (!empty($images)) {
                $first_image = $images[0];
                $image_url = str_replace($_SERVER['DOCUMENT_ROOT'], '', $first_image);
            } else {
                $image_url = 'placeholder.png'; // 使用一个默认的占位图
            }
            ?>
            <div class="folder">
                <a href="gallery.php?dir=<?php echo urlencode($folder); ?>">
                    <img src="<?php echo htmlspecialchars($image_url); ?>" alt="<?php echo htmlspecialchars($folder_name); ?>">
                    <br>
                    <?php echo htmlspecialchars($folder_name); ?>
                </a>
            </div>
        <?php endforeach; ?>
    </div>
   <div class="pagination">
    <?php if ($page > 1): ?>
        <a href="?page=<?php echo $page - 1; ?>&search=<?php echo urlencode($search); ?>">上一页</a>
    <?php else: ?>
        <span class="disabled">上一页</span>
    <?php endif; ?>

    <span class="page-info">第 <?php echo $page; ?> 页 / 共 <?php echo $total_pages; ?> 页</span>

    <?php if ($page < $total_pages): ?>
        <a href="?page=<?php echo $page + 1; ?>&search=<?php echo urlencode($search); ?>">下一页</a>
    <?php else: ?>
        <span class="disabled">下一页</span>
    <?php endif; ?>

    <form class="jump-form" action="" method="get">
        <input type="hidden" name="search" value="<?php echo htmlspecialchars($search); ?>">
        <input type="number" name="page" min="1" max="<?php echo $total_pages; ?>" value="<?php echo $page; ?>">
        <input type="submit" value="跳转">
    </form>
</div>
    </div>
</body>
</html>
